/* Place in the public domain by Sam Trenholme 2000 */
/* js_string routines that depend on the code page (encoding) that we
   are in */

#include "JessStr.h"

/* js_newline_chars: returns a set of newline characters for a given
                     encoding
   input: an empty js_string object we look at the codepage of
   output: JS_ERROR (-1) on error, JS_SUCCESS (1) on success */

int js_newline_chars(js_string *js) {
   
    /* Sanity check */
    if(js_has_sanity(js) == -1)
        return -1;
   
    /* Handle different encodings differently */ 
    switch(js->encoding) {
        case JS_BINARY:
            js->unit_count = 0;
            return JS_SUCCESS;
        case JS_US_ASCII:
            if(js->unit_size != 1)
                return -1; /* This string is not sane */ 
            if(js_octets(js) < 2)
                return -1; /* No overflows ever */
            *(js->string) = '\r';
            *(js->string + 1) = '\n';
            js->unit_count = 2;
            return JS_SUCCESS;
        }

     /* We only get here if it is an unhandled encoding */
     return JS_ERROR;

     }
 
/* js_space_chars: returns a set of whitespace characters for a given
                   encoding
   input: an empty js_string object we look at the codepage of
   output: JS_ERROR (-1) on error, JS_SUCCESS (1) on success */

int js_space_chars(js_string *js) {
   
    /* Sanity check */
    if(js_has_sanity(js) == -1)
        return -1;
   
    /* Handle different encodings differently */ 
    switch(js->encoding) {
        case JS_BINARY:
            js->unit_count = 0;
            return JS_SUCCESS;
        case JS_US_ASCII:
            if(js->unit_size != 1)
                return -1; /* This string is not sane */ 
            if(js_octets(js) < 2)
                return -1; /* No overflows ever */
            *(js->string) = ' ';
            *(js->string + 1) = '\t';
            js->unit_count = 2;
            return JS_SUCCESS;
        }

     /* We only get here if it is an unhandled encoding */
     return JS_ERROR;

     }
 
